@@ -17,7 +17,7 @@ use Bio::Gonzales::Util::File qw/open_on_demand slurpc expand_home/;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.062'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 @EXPORT      = qw(mslurp mspew lslurp miterate lspew dict_slurp dict_spew xcsv_slurp miterate_hash);
 %EXPORT_TAGS = ();
@@ -77,7 +77,7 @@ sub dict_slurp {
       }
       $raw_row =~ s/\r$//;
       chomp $raw_row;
-      @header = split /$c{sep}/, $raw_row;
+      @header = split /$c{sep}/, $raw_row, -1;
       @header = ref $vidx ? @header[@$vidx] : ( $header[$vidx] ) if ( defined $vidx && $vidx ne 'all' );
       last;
     }
@@ -94,7 +94,7 @@ sub dict_slurp {
 
     next if ( $record_filter && !$record_filter->($_) );
 
-    my @r = split /$c{sep}/;
+    my @r = split /$c{sep}/, $_, -1;
 
     for my $kidx (@kidcs) {
 
@@ -177,7 +177,7 @@ sub mslurp {
 
       $raw_row =~ s/\r\n/\n/;
       chomp $raw_row;
-      @header = split /$c{sep}/, $raw_row;
+      @header = split /$c{sep}/, $raw_row, -1;
       last;
     }
   }
@@ -192,9 +192,10 @@ sub mslurp {
 
     next if ( $record_filter && !$record_filter->($_) );
 
-    my @row = split /$c{sep}/;
+    my @row = split /$c{sep}/, $_, -1;
 
     push @row_names, shift @row if ( $c{row_names} );
+    @row = map { $_ eq $c{na_value} ? undef : $_ } @row if($c{na_value});
 
     push @m, ( @col_idx ? [ @row[@col_idx] ] : \@row );
   }
@@ -261,7 +262,7 @@ sub miterate {
       next if (/^\s*$/);
       next if ( $record_filter && !$record_filter->($_) );
 
-      my @row = split /$c{sep}/;
+      my @row = split /$c{sep}/, $_, -1;
       return \@row;
 
     }
