@@ -12,7 +12,7 @@ use Bio::Gonzales::Util::File;
 
 use Carp;
 
-our $VERSION = '0.062'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 around BUILDARGS => sub {
   my $orig  = shift;
@@ -49,7 +49,7 @@ sub next_seq {
 
   my $fhi = $self->_fhi;
   my $def = $fhi->();
-  unless ($def) {
+  unless (defined $def) {
     $self->close;
     return;
   }
