@@ -13,6 +13,8 @@ use IO::Uncompress::Bunzip2 qw($Bunzip2Error);
 use File::Which qw/which/;
 use Bio::Gonzales::Util::IO::Compressed;
 
+use constant BG_MAGIC => "\037\213\010\4\0\0\0\0\0\377\6\0\102\103\2\0\0\0";
+
 our %ZMODES = (
   '>'  => 'wb',
   '>>' => 'ab',
@@ -21,14 +23,14 @@ our %ZMODES = (
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.062'; # VERSION
+our $VERSION = '0.066'; # VERSION
 our $EXTERNAL_GZ    = which('gzip');    #which('pigz') // which('gzip');
 our $EXTERNAL_BZIP2 = which('bzip2');
 
 @EXPORT      = qw(glob_regex epath bname openod spath);
 %EXPORT_TAGS = ();
 @EXPORT_OK
-  = qw(expand_path slurpc basename regex_glob open_on_demand is_newer splitpath %ZMODES is_archive expand_home gonzopen);
+  = qw(expand_path slurpc basename regex_glob open_on_demand is_newer splitpath %ZMODES is_archive expand_home gonzopen gz_type);
 
 sub epath { expand_path(@_) }
 
@@ -124,7 +126,7 @@ sub open_on_demand {
     $fh_was_open = 1;
   } elsif ( !ref($src) ) {
     $src = expand_home($src);
-    if ( $src =~ /.+?\.gz$/i ) {
+    if ( $src =~ /.+?\.b?gz$/i || ($mode eq '<' && -e $src && gz_type($src)) ) {
       if ($EXTERNAL_GZ) {
         $fh = _pipe_z( $EXTERNAL_GZ, $src, $mode );
       } else {
@@ -183,7 +185,7 @@ sub _pipe_z {
 sub is_archive {
   my $f = shift;
 
-  if ( $f =~ /.+?\.gz$/i ) {
+  if ( $f =~ /.+?\.b?gz$/i ) {
     return 'gz';
   } elsif ( $f =~ /.+?\.bz2$/i ) {
     return 'bz2';
@@ -212,6 +214,25 @@ sub is_fh {
   return;
 }
 
+sub gz_type {
+  my $f = shift;
+
+  open my $fh, '<', $f or die "Can't open filehandle: $!";
+  binmode $fh;
+  my $size = length(BG_MAGIC);
+  my $nread = read( $fh, my $buffer, $size );
+  close $fh;
+  return unless ( $nread == $size );
+
+  if ( unpack( 'H16', $buffer ) eq unpack( 'H16', BG_MAGIC ) ) {
+    return 'bgzf';
+  } elsif ( unpack( 'H2', $buffer ) eq unpack( 'H2', BG_MAGIC ) ) {
+    return 'gzip';
+  } else {
+    return;
+  }
+}
+
 1;
 __END__
 
